@@ -51,6 +51,9 @@ parser.add_option(
     "-d", "--daemon", action="store_true",
     default=radicale.config.getboolean("server", "daemon"),
     help="launch as daemon")
+parser.add_option(
+    "-f", "--foreground", action="store_false", dest="daemon",
+    help="launch in foreground (opposite of --daemon)")
 parser.add_option(
     "-H", "--host",
     default=radicale.config.get("server", "host"),
@@ -63,6 +66,9 @@ parser.add_option(
     "-s", "--ssl", action="store_true",
     default=radicale.config.getboolean("server", "ssl"),
     help="use SSL connection")
+parser.add_option(
+    "-S", "--no-ssl", action="store_false", dest="ssl",
+    help="do not use SSL connection (opposite of --ssl)")
 parser.add_option(
     "-k", "--key",
     default=radicale.config.get("server", "key"),
