@@ -49,22 +49,21 @@ except ImportError:
 from radicale import acl, config, ical, xmlutils
 
 
-VERSION = "0.3"
+VERSION = "0.4"
 
 def _check(request, function):
     """Check if user has sufficient rights for performing ``request``."""
+    # ``_check`` decorator can access ``request`` protected functions
+    # pylint: disable=W0212
     authorization = request.headers.get("Authorization", None)
     if authorization:
         challenge = authorization.lstrip("Basic").strip().encode("ascii")
-        # ``_check`` decorator can access ``request`` protected functions
-        # pylint: disable=W0212
         plain = request._decode(base64.b64decode(challenge))
-        # pylint: enable=W0212
         user, password = plain.split(":")
     else:
         user = password = None
 
-    if request.server.acl.has_right(user, password):
+    if request.server.acl.has_right(request._calendar.owner, user, password):
         function(request)
     else:
         request.send_response(client.UNAUTHORIZED)
@@ -72,6 +71,7 @@ def _check(request, function):
             "WWW-Authenticate",
             "Basic realm=\"Radicale Server - Password Required\"")
         request.end_headers()
+    # pylint: enable=W0212
 
 
 class HTTPServer(server.HTTPServer):
@@ -148,10 +148,15 @@ class CalendarHTTPHandler(server.BaseHTTPRequestHandler):
     # Naming methods ``do_*`` is OK here
     # pylint: disable=C0103
 
-    @check_rights
     def do_GET(self):
         """Manage GET request."""
-        item_name = (xmlutils.name_from_path(self.path))
+        self.do_HEAD()
+        self.wfile.write(self._answer)
+
+    @check_rights
+    def do_HEAD(self):
+        """Manage HEAD request."""
+        item_name = xmlutils.name_from_path(self.path)
         if item_name:
             # Get calendar item
             items = self._calendar.timezones
@@ -165,13 +170,13 @@ class CalendarHTTPHandler(server.BaseHTTPRequestHandler):
             answer_text = self._calendar.text
             etag = self._calendar.etag
 
-        answer = answer_text.encode(self._encoding)
+        self._answer = answer_text.encode(self._encoding)
         self.send_response(client.OK)
-        self.send_header("Content-Length", len(answer))
+        self.send_header("Content-Length", len(self._answer))
         self.send_header("Content-Type", "text/calendar")
+        self.send_header("Last-Modified", self._calendar.last_modified)
         self.send_header("ETag", etag)
         self.end_headers()
-        self.wfile.write(answer)
 
     @check_rights
     def do_DELETE(self):
@@ -179,12 +184,12 @@ class CalendarHTTPHandler(server.BaseHTTPRequestHandler):
         item = self._calendar.get_item(xmlutils.name_from_path(self.path))
         if item and self.headers.get("If-Match", item.etag) == item.etag:
             # No ETag precondition or precondition verified, delete item
-            answer = xmlutils.delete(self.path, self._calendar)
+            self._answer = xmlutils.delete(self.path, self._calendar)
 
             self.send_response(client.NO_CONTENT)
-            self.send_header("Content-Length", len(answer))
+            self.send_header("Content-Length", len(self._answer))
             self.end_headers()
-            self.wfile.write(answer)
+            self.wfile.write(self._answer)
         else:
             # No item or ETag precondition not verified, do not delete item
             self.send_response(client.PRECONDITION_FAILED)
@@ -192,20 +197,20 @@ class CalendarHTTPHandler(server.BaseHTTPRequestHandler):
     def do_OPTIONS(self):
         """Manage OPTIONS request."""
         self.send_response(client.OK)
-        self.send_header("Allow", "DELETE, GET, OPTIONS, PROPFIND, PUT, REPORT")
+        self.send_header("Allow", "DELETE, HEAD, GET, OPTIONS, PROPFIND, PUT, REPORT")
         self.send_header("DAV", "1, calendar-access")
         self.end_headers()
 
     def do_PROPFIND(self):
         """Manage PROPFIND request."""
         xml_request = self.rfile.read(int(self.headers["Content-Length"]))
-        answer = xmlutils.propfind(self.path, xml_request, self._calendar)
+        self._answer = xmlutils.propfind(self.path, xml_request, self._calendar)
 
         self.send_response(client.MULTI_STATUS)
         self.send_header("DAV", "1, calendar-access")
-        self.send_header("Content-Length", len(answer))
+        self.send_header("Content-Length", len(self._answer))
         self.end_headers()
-        self.wfile.write(answer)
+        self.wfile.write(self._answer)
 
     @check_rights
     def do_PUT(self):
@@ -234,11 +239,11 @@ class CalendarHTTPHandler(server.BaseHTTPRequestHandler):
     def do_REPORT(self):
         """Manage REPORT request."""
         xml_request = self.rfile.read(int(self.headers["Content-Length"]))
-        answer = xmlutils.report(self.path, xml_request, self._calendar)
+        self._answer = xmlutils.report(self.path, xml_request, self._calendar)
 
         self.send_response(client.MULTI_STATUS)
-        self.send_header("Content-Length", len(answer))
+        self.send_header("Content-Length", len(self._answer))
         self.end_headers()
-        self.wfile.write(answer)
+        self.wfile.write(self._answer)
 
     # pylint: enable=C0103
