@@ -31,6 +31,5 @@ from radicale import config
 
 def load():
     """Load list of available ACL managers."""
-    module = __import__("radicale.acl", globals(), locals(),
-                        [config.get("acl", "type")])
+    module = __import__("radicale.acl", fromlist=[config.get("acl", "type")])
     return getattr(module, config.get("acl", "type"))
